@@ -6,7 +6,7 @@ require Exporter;
 use Test::More import => ['!pass'];
 use Carp qw/croak/;
 
-use parent qw(Test::Builder::Module Exporter);
+use base qw(Test::Builder::Module Exporter);
 
 our @EXPORT    = qw(is_true is_false is_defined is_undef is_dying grow_stack leak_free_ok);
 our @EXPORT_OK = qw(is_true is_false is_defined is_undef is_dying grow_stack leak_free_ok);
